#ifndef NT2_INCLUDE_FUNCTIONS_LDEXP_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LDEXP_HPP_INCLUDED

#include <nt2/ieee/include/functions/ldexp.hpp>

#endif
